@@ -21,14 +21,14 @@ B<For internal use only>.
 
 =head1 VERSION
 
-Version 0.5.0
+Version 0.5.1
 
 =cut
 
-our $VERSION = '0.5.0';
+our $VERSION = '0.5.1';
 
 sub _non_tag_text_unit_consume_regex {
-    return qr{(?:[\<\&]|^\n?$)}ms;
+    return qr{(?:[\<]|^\n?$)}ms;
 }
 
 sub _generate_non_tag_text_event
